# pixilate 

> convert images to true color format using python :bulb:



## Contents
- [Installation](#install)
- [Running](#run)
- [Troubleshoot](#ts)
- [Like](#like)
- [Contributing](#cb)
- [Author](#author)
- [License](#ls)


<a name="install"></a>
## Install :sparkles:

```pip install pixilate```


<a name="run"></a>
## Running :running:

  ```pixilate [filepath] [savetofile]```
  
 | Param | Type | Description |
| --- | --- | --- |
| filepath | <code>path</code> | The path to the file you want to convert |
| savetofile | <code>bool: 1 or 0</code> | if you want to save your output to a file (defaults to 0) |


<a name="ts"></a>
## Troubleshoot :scream:

If the output seems to be some text or the image doesnt seemed to be colored properly you may have a terminal app that does not support [True Color](https://en.wikipedia.org/wiki/Color_depth#True_color_(24-bit)) , you can find a list of terminal apps that do support it right now [here](https://gist.github.com/XVilka/8346728) and many others working on them.

<a name="like"></a>
## Like :+1:
If you found this interesting, leave a star :star:

<a name="cb"></a>
## Contributing :books:

Contributions welcome; Please submit all pull requests the against master branch.

<a name="author"></a>
## Author :monkey:

[c00kie17](https://github.com/c00kie17)

<a name="ls"></a>
## License :page_with_curl:

 - [**MIT**](http://opensource.org/licenses/MIT)

